#
# spec file for package lychee
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lychee
Version:        0.18.0~0
Release:        1.1
Summary:        Fast, async, stream-based link checker written in Rust
License:        Apache-2.0 OR MIT
URL:            https://lychee.cli.rs
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  libopenssl-devel
ExclusiveArch:  %{rust_tier1_arches}

%description
Fast, async, stream-based link checker written in Rust. Finds broken URLs and mail addresses inside Markdown, HTML, reStructuredText, websites and more!

%prep
%autosetup -p1 -a1

%build
%{cargo_build} --all

%install
%{cargo_install -p lychee-bin}

%files
%license LICENSE-APACHE
%license LICENSE-MIT
%{_bindir}/%{name}

%changelog
* Thu Dec 19 2024 alessio.biancalana@suse.com
- Update to version 0.18.0~0:
  * chore: release v0.18.0 (#1554)
  * Fix nightly docker image (#1590)
  * Bump the dependencies group across 1 directory with 11 updates (#1589)
  * Introduce --root-dir (#1576)
  * Allow Docker pushes on release branches (#1568)
  * Fix retries (#1573)
  * Pass along --max-retries config option (#1572)
  * Bump the dependencies group with 4 updates (#1571)
  * Bump the dependencies group with 4 updates (#1570)
  * Bump the dependencies group with 4 updates (#1566)
  * Rename `fail_map` to `error_map` for improved clarity in response statistics (#1560)
  * Add quirks support for `youtube-nocookie.com` and youtube embed URLs (#1563)
  * Update all Docker images to Debian Bookworm (#1558)
  * Support excluded paths in `--dump-inputs` (#1556)
  * Improve robustness of cache integration test (#1557)
  * Support underscores in Markdown URLs (#1555)
  * Bump the dependencies group across 1 directory with 7 updates (#1552)
  * Fix: Bring back error output for links (#1553)
* Sat Nov  9 2024 alessio.biancalana@suse.com
- Update to version 0.17.0~0:
  * chore: release v0.17.0 (#1549)
  * Add Forui to README.md's users section (#1551)
  * Bump the dependencies group across 1 directory with 12 updates (#1544)
  * Ignore casing when processing markdown fragments + check for percent encoded ancors (#1535)
  * Refactor cache handling test to make it more robust (#1548)
  * Fix format option in configuration file (#1547)
  * Fix skipping of email addresses in stylesheets (#1546)
  * Add support for relative links (#1489)
  * Box Octocrab error as it is too large (#1543)
  * Update link check action (#1542)
  * Fix example usage of headers in configuration file (#1540)
  * Add interesting projects who use lychee (#1537)
  * Don't check prefix attribute (#1536)
  * Add OWASP Threat Dragon to users
  * Update `pkg-url` of cargo binstall (#1532)
  * Bump the dependencies group with 3 updates (#1530)
  * Allow excluding cache based on status code (#1403)
  * Ignore textContent links in html nodes (#1528)
  * fix:  The 'as' keyword in the Dockerfile should be uppercase
  * Respect timeout when retrieving archived link (#1526)
  * Update TOC in README.md
  * fix: Remove tokio console subscriber (#1524)
  * Disable Wayback machine tests
  * Delete release-plz.toml
  * feat: Add tests for `dns-prefetch` (#1522)
  * Exclude `rel=dns-prefetch` links (#1520)
  * Extend documentation on excluding links
  * Improve docs for fragment checker
  * README: The Git home page and Git Credential Manager use lychee (#1519)
  * Don't check preconnect links (#1187)
  * Use custom token here to allow triggering other pipelines
  * Use custom token here to allow triggering other pipelines
  * Bump the dependencies group with 6 updates (#1516)
* Mon Oct 14 2024 alessio.biancalana@suse.com
- Update to version 0.16.1:
  * chore: release (#1514)
  * markdown.rs: make first line a top-level heading (#1511)
  * Listen to additional release triggers for binary builds
  * listen to more release triggers for binary builds
  * chore: release (#1512)
  * Don't add changelog files
  * Cleanup `.gitignore` file
  * Add release-plz and clean up workflows (#1510)
  * Bump the dependencies group across 1 directory with 8 updates (#1509)
  * README: add tldr-pages as user (#1508)
  * Disable pedantic clippy lint
  * Test ignored files
  * Test hidden files
  * Update example
  * Skip ignored and hidden files by default
  * Remove is_symlink check, because it's mutually exclusive to is_file
  * Handle path exclusions when walking directories
  * Update README.md test to trim whitespaced lines & update README.md
  * Update tests
  * Make gitignored files configurable and disable by default
  * Replace jwalk with ignore
  * Bump the dependencies group across 1 directory with 13 updates (#1502)
  * Extend compact format (#1497)
  * Bump the dependencies group with 2 updates (#1494)
  * chore(docs): mention MacPorts install in README.md (#1491)
  * Bump the dependencies group with 4 updates (#1490)
  * Mention Chocolatey
  * Bump the dependencies group with 5 updates (#1488)
  * Bump the dependencies group with 6 updates (#1486)
  * Run cargo nextest in CI and enable all tests (#1483)
  * test: fail when interpreting md footnote as link (#1479)
  * ci: fix wrong cpu-arch tag on macos release assets (#1484)
  * Properly wire in tokio-console (#1482)
  * Harmonizes naming pattern of pre-built binaries and unlocks latest permalink (#1464)
  * Fix: Windows drive paths misidentified as URLs (#1460)
  * Bump docker/build-push-action from 5 to 6 in the dependencies group (#1449)
  * Bump the dependencies group across 1 directory with 29 updates (#1478)
  * Updated pulldown-cmark dependency and fixed maths parsing (#1473)
  * README: add openSUSE Tumbleweed to the installation instructions (#1470)
  * feat(clap): show help menu on no args as well (#1458)
  * README: Add Nixpkgs to Installation (#1448)
  * Screencast update (#1445)
  * Add response formatter; refactor stats formatter (#1398)
  * Extend documentation for `RequestChain` (#1442)
  * Update TROUBLESHOOTING.md (#1440)
  * Add a way to handle "pretty URLs", i.e. URIs without `.html` extension (#1422)
  * Don't trim mailto: prefix when converting a Uri into a string (#1438)
  * Add Execa to list of users (#1435)
  * Exclude `tel` scheme from being checked (#1429)
  * Fix typo in pre-commit config in README (#1424)
  * Fix clippy errors (#1423)
* Sat Jul 20 2024 Alessio Biancalana <alessio.biancalana@suse.com>
- Update to version 0.15.1:
  * Gracefully handle invalid URLs
  * Chain visibility
  * Fix spelling
